from rdkit import Chem
from rdkit.Chem import AllChem
from collections import defaultdict
from rdkit.Chem import rdFMCS
from rdkit.Chem import Draw


#needed for show_mols
from rdkit.Chem.Draw import rdMolDraw2D
import cairosvg
import math
import os

#inspired by https://github.com/rdkit/UGM_2020/blob/master/Notebooks/Landrum_WhatsNew.ipynb
#from https://colab.research.google.com/drive/1mf5Oce15L_57Yj7bWbSjdmURELMcj1eV?usp=sharing#scrollTo=Ni58g7BkkkAE



def save_mols(mols, mols_per_row = 5, size=200, min_font_size=12, legends=[], file_name=''):
  """
  The show_mols function accepts a list of molecules and their corresponding legends,
  and shows them in a grid format. The function is designed to work with the RDKit's 
  Draw.MolsToGridImage function, which allows for the creation of SVG images using 
  the Python package CairoSVG.
  
  :param mols: Used to pass a list of molecules to the function.
  :param mols_per_row=5: Used to specify the number of molecules to display in each row.
  :param size=200: Used to set the size of the image.
  :param min_font_size=12: Used to set the minimum font size for the legends.
  :param legends=[]: Used to show the name of each molecule.
  :param file_name='': Used to save the drawing as an svg file.
  :return: A matplotlib plot of the molecules.
  
  :doc-author: Julian M. Kleber
  """
    
  if legends and len(legends) < len(mols):
    print('legends is too short')
    return None

  mols_per_row = min(len(mols), mols_per_row)  
  rows = math.ceil(len(mols)/mols_per_row)
  d2d = rdMolDraw2D.MolDraw2DSVG(mols_per_row*size,rows*size,size,size)
  d2d.drawOptions().minFontSize = min_font_size
  d2d.drawOptions().legendFontSize = min_font_size
  if legends:
    d2d.DrawMolecules(mols, legends=legends)
  else:
    d2d.DrawMolecules(mols)
  d2d.FinishDrawing()

  if file_name:
    with open('d2d.svg', 'w') as f:
      f.write(d2d.GetDrawingText())
      if 'pdf' in file_name:
        cairosvg.svg2pdf(url='d2d.svg', write_to=file_name)
      else:
        cairosvg.svg2png(url='d2d.svg', write_to=file_name)
      os.remove('d2d.svg')


from radiant.plot_compounds import save_mols

def test_plot_compounds(): 
    """
    The test_plot_compounds function plots a set of compounds in the same figure.
    It takes as input a list of smiles strings and plots them in the same figure.
    
    :return: A list of matplotlib figures.
    
    :doc-author: Trelent
    """
    from rdkit import Chem
    
    smiles_list = ['c1ccccc1','Cc1occc1C(=O)Nc2ccccc2', 'CN1CCN(S(=O)(C2=CC=C(OCC)C(C3=NC4=C(N(C)N=C4CCC)C(N3)=O)=C2)=O)CC1']
    mols = [Chem.MolFromSmiles(x) for x in smiles_list]
    legends = ['1', '2', '3']

    save_mols(mols, legends=legends, file_name='radiant/tests/test.png')
    save_mols(mols, legends=legends, file_name='radiant/tests/test_large.png', min_font_size=30)


import setuptools

with open("README.md", "r") as fh:

    long_description = fh.read()

setuptools.setup(
    name="radiant-rdkit",
    version="0.2.0",
    author="Julian M. Kleber",
    author_email="julian.kleber@sail.black",
    description="short package to make publication quality rdkit plots",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://codeberg.org/sail.black/acheeve.git",
    packages=setuptools.find_packages(include=["radiant*"]),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU Affero General Public License v3 or later (AGPLv3+)",
        "Operating System :: OS Independent",
    ],
    install_requires=[
          'rdkit',
          'cairosvg'
      ],
    python_requires=">=3.9",
)
